==> kendo-barcodes-vue-wrapper-2018.1.117-dev.2051112.tgz: package/docs/qrcode/index.md <==
---
title: Overview
page_title: Overview - QRCode - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI QRCode wrapper for Vue delivers and use the component in Vue projects."
slug: overview_qrcode
position: 1
---

# QRCode Overview

[QRCodes](https://en.wikipedia.org/wiki/QR_code) take a piece of information from a transitory media and help you generate Canvas and [Scalable Vector Graphics (SVG)](https://www.w3.org/Graphics/SVG/) images which represent QR (Quick Response) codes and can be quickly read by a cell phone.

The QRCode renders all graphics on the client by using Canvas or SVG and supports [different conventions](https://docs.telerik.com/kendo-ui/controls/barcodes/qrcode/overview#general-conventions) for the values and a fallback to VML for older browsers.

The QRCode wrapper for Vue is a client-side wrapper for the [Kendo UI QRCode](http://docs.telerik.com/kendo-ui/api/javascript/ui/qrcode) widget.

## Basic Usage

The following example demonstrates the QRCode in action.

```html-preview
<div id="vueapp" class="vue-app">
	<kendo-qrcode :value="'geo:42.65049,23.37925,100'"
				  :error-collection="'H'"
				  :size="120"
				  :encoding="'UTF_8'"
				  :color="'#166a83'">
	</kendo-qrcode>
    <kendo-qrcode :value="qrCodeValue" :size="200" :encoding="'UTF_8'"></kendo-qrcode>
    <input v-model="qrCodeValue"/>
</div>
```
```js
Vue.use(BarcodesInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            qrCodeValue: 'Some Text'
        }
    }
})
```

## Suggested Links

* [Kendo UI QRCode for jQuery](https://docs.telerik.com/kendo-ui/controls/barcodes/qrcode/overview)
* [API Reference of the QRCode Widget](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/qrcode)

==> kendo-barcodes-vue-wrapper-2018.3.911.tgz: package/docs/qrcode/index.md <==
---
title: Overview
page_title: Overview - QRCode - Kendo UI for Vue
description: "Get an overview of the features the Kendo UI QRCode wrapper for Vue delivers and use the component in Vue projects."
slug: overview_qrcode
position: 1
---

# QRCode Overview

[QRCodes](https://en.wikipedia.org/wiki/QR_code) take a piece of information from a transitory media and help you generate Canvas and [Scalable Vector Graphics (SVG)](https://www.w3.org/Graphics/SVG/) images which represent QR (Quick Response) codes and can be quickly read by a cell phone.

The QRCode renders all graphics on the client by using Canvas or SVG and supports [different conventions](https://docs.telerik.com/kendo-ui/controls/barcodes/qrcode/overview#general-conventions) for the values and a fallback to VML for older browsers.

The QRCode wrapper for Vue is a client-side wrapper for the [Kendo UI QRCode](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/qrcode) widget.

## Basic Usage

The following example demonstrates the QRCode in action.

```html-preview
<div id="vueapp" class="vue-app">
	<kendo-qrcode :value="'geo:42.65049,23.37925,100'"
				  :error-collection="'H'"
				  :size="120"
				  :encoding="'UTF_8'"
				  :color="'#166a83'">
	</kendo-qrcode>
    <kendo-qrcode :value="qrCodeValue" :size="200" :encoding="'UTF_8'"></kendo-qrcode>
    <input v-model="qrCodeValue"/>
</div>
```
```js
Vue.use(BarcodesInstaller);

new Vue({
    el: "#vueapp",
    data: function() {
        return {
            qrCodeValue: 'Some Text'
        }
    }
})
```

## Suggested Links

* [Kendo UI QRCode for jQuery](https://docs.telerik.com/kendo-ui/controls/barcodes/qrcode/overview)
* [API Reference of the QRCode Widget](https://docs.telerik.com/kendo-ui/api/javascript/dataviz/ui/qrcode)
